Models
==============


PhrasesModel
^^^^^^^^^^^^^^^^^^

The **PhrasesModel** is used to build bgrams.
In this case, it's a wrapper around `Gensim Phrases <https://radimrehurek.com/gensim/models/phrases.html>`_

.. autoclass:: datawords.models.PhrasesModel
               :members:


Word2VecHelper
^^^^^^^^^^^^^^^^^^

A wrapper around `Gensim Word2Vec <https://radimrehurek.com/gensim/models/word2vec.html>`_

.. autoclass:: datawords.models.Word2VecHelper
               :members:
